GlassAnimationCurve enum

Animation curve types for native glass interpolation. Must match native GlassAnimationCurve enum.

Inheritance
Available extensions

Values

linear → const GlassAnimationCurve

Linear interpolation (t)

easeOut → const GlassAnimationCurve

Ease out quadratic (1 - (1-t)^2)

easeOutCubic → const GlassAnimationCurve

Ease out cubic (1 - (1-t)^3) - default, matches Flutter's easeOutCubic

easeInOut → const GlassAnimationCurve

Ease in-out quadratic (t < 0.5 ? 2t^2 : 1 - (-2t+2)^2/2)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GlassAnimationCurve>
A constant List of the values in this enum, in order of their declaration.