AppearanceClient class

Client for AppearanceService.

Handles window chrome, shadow, background.

Inheritance

Constructors

AppearanceClient(NativeBridge bridge)

Properties

bridge NativeBridge
Protected access to bridge for subclasses that need direct bridge access.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceName String
The service name (must match native side).
no setteroverride

Methods

applyAppearance(String id, PaletteAppearance appearance) Future<void>
Apply full appearance config.
dispose() → void
Clean up all subscriptions.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onEvent(String eventName, void callback(NativeEvent)) → void
Subscribe to events from this service.
inherited
onWindowEvent(String windowId, String eventName, void callback(NativeEvent)) → void
Subscribe to events for a specific window.
inherited
send<T>(String command, {String? windowId, Map<String, dynamic>? params}) Future<T?>
Send a command to this service.
inherited
sendFireAndForget(String command, {String? windowId, Map<String, dynamic>? params}) → void
Send a command, fire and forget.
inherited
sendForMap(String command, {String? windowId, Map<String, dynamic>? params}) Future<Map<String, dynamic>?>
Send a command expecting a Map result.
inherited
setBackgroundColor(String id, Color? color) Future<void>
Set background color.
setBlur(String id, {bool enabled = true, String material = 'hudWindow'}) Future<void>
Enable or disable system blur effect.
setCornerRadius(String id, double radius) Future<void>
Set corner radius.
setShadow(String id, PaletteShadow shadow) Future<void>
Set shadow style.
setTransparent(String id, bool transparent) Future<void>
Set transparency.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited