capturePadding property
Extra padding around the window to capture. Useful for effects that extend beyond the window bounds (like liquid glass circles).
Implementation
final EdgeInsets capturePadding;
Extra padding around the window to capture. Useful for effects that extend beyond the window bounds (like liquid glass circles).
final EdgeInsets capturePadding;