BackgroundCaptureEvent class

Event data for background capture events.

Constructors

BackgroundCaptureEvent({required String paletteId, required String type, required Map<String, dynamic> data})
const

Properties

data Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setterinherited
paletteId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited