FocusClient class

Client for FocusService.

Handles focus management.

Inheritance

Constructors

FocusClient(NativeBridge bridge)

Properties

bridge NativeBridge
Protected access to bridge for subclasses that need direct bridge access.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceName String
The service name (must match native side).
no setteroverride

Methods

dispose() → void
Clean up all subscriptions.
inherited
focus(String id) Future<void>
Focus a window.
focusMainWindow() Future<void>
Activate the main app window.
hasFocus(String id) Future<bool>
Check if window has focus.
hideApp() Future<void>
Hide the app entirely (returns to previously active app).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onEvent(String eventName, void callback(NativeEvent)) → void
Subscribe to events from this service.
inherited
onFocused(String id, void callback()) → void
Called when window gains focus.
onUnfocused(String id, void callback()) → void
Called when window loses focus.
onWindowEvent(String windowId, String eventName, void callback(NativeEvent)) → void
Subscribe to events for a specific window.
inherited
restoreFocus(FocusRestoreMode mode) Future<void>
Restore focus based on mode (orchestrated by Dart).
send<T>(String command, {String? windowId, Map<String, dynamic>? params}) Future<T?>
Send a command to this service.
inherited
sendFireAndForget(String command, {String? windowId, Map<String, dynamic>? params}) → void
Send a command, fire and forget.
inherited
sendForMap(String command, {String? windowId, Map<String, dynamic>? params}) Future<Map<String, dynamic>?>
Send a command expecting a Map result.
inherited
setPolicy(String id, FocusPolicy policy) Future<void>
Set focus policy.
toString() String
A string representation of this object.
inherited
unfocus(String id) Future<void>
Remove focus from a window.

Operators

operator ==(Object other) bool
The equality operator.
inherited