FrameClient class

Client for FrameService.

Handles position and size.

Inheritance

Constructors

FrameClient(NativeBridge bridge)

Properties

bridge NativeBridge
Protected access to bridge for subclasses that need direct bridge access.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceName String
The service name (must match native side).
no setteroverride

Methods

dispose() → void
Clean up all subscriptions.
inherited
getBounds(String id) Future<Rect>
Get current bounds.
getPosition(String id) Future<Offset>
Get current position.
getSize(String id) Future<Size>
Get current size.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onEvent(String eventName, void callback(NativeEvent)) → void
Subscribe to events from this service.
inherited
onMoved(String id, void callback(Offset position)) → void
Called when window moves.
onResized(String id, void callback(Size size)) → void
Called when window resizes.
onWindowEvent(String windowId, String eventName, void callback(NativeEvent)) → void
Subscribe to events for a specific window.
inherited
send<T>(String command, {String? windowId, Map<String, dynamic>? params}) Future<T?>
Send a command to this service.
inherited
sendFireAndForget(String command, {String? windowId, Map<String, dynamic>? params}) → void
Send a command, fire and forget.
inherited
sendForMap(String command, {String? windowId, Map<String, dynamic>? params}) Future<Map<String, dynamic>?>
Send a command expecting a Map result.
inherited
setBounds(String id, Rect bounds, {bool animate = false, int? durationMs, String? curve}) Future<void>
Set window bounds (position + size).
setDraggable(String id, {required bool draggable}) Future<void>
Enable or disable dragging for a window.
setPosition(String id, Offset position, {String? anchor, bool animate = false, int? durationMs, String? curve}) Future<void>
Set window position.
setSize(String id, Size size, {bool animate = false, int? durationMs, String? curve}) Future<void>
Set window size.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited