InputClient class

Client for InputService.

Handles keyboard capture, pointer, cursor.

Inheritance

Constructors

InputClient(NativeBridge bridge)

Properties

bridge NativeBridge
Protected access to bridge for subclasses that need direct bridge access.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceName String
The service name (must match native side).
no setteroverride

Methods

captureKeyboard(String id, {Set<LogicalKeyboardKey>? keys, bool allKeys = false}) Future<void>
Capture keyboard events.
capturePointer(String id) Future<void>
Capture all pointer events.
dispose() → void
Clean up all subscriptions.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onClickOutside(String id, void callback(Offset position)) → void
Called on click outside.
onEvent(String eventName, void callback(NativeEvent)) → void
Subscribe to events from this service.
inherited
onKeyDown(String id, void callback(LogicalKeyboardKey key, Set<LogicalKeyboardKey> modifiers)) → void
Called on key down.
onKeyUp(String id, void callback(LogicalKeyboardKey key)) → void
Called on key up.
onPointerEnter(String id, void callback()) → void
Called on pointer enter.
onPointerExit(String id, void callback()) → void
Called on pointer exit.
onWindowEvent(String windowId, String eventName, void callback(NativeEvent)) → void
Subscribe to events for a specific window.
inherited
releaseKeyboard(String id) Future<void>
Release keyboard capture.
releasePointer(String id) Future<void>
Release pointer capture.
resetCursor(String id) Future<void>
Reset cursor to default.
send<T>(String command, {String? windowId, Map<String, dynamic>? params}) Future<T?>
Send a command to this service.
inherited
sendFireAndForget(String command, {String? windowId, Map<String, dynamic>? params}) → void
Send a command, fire and forget.
inherited
sendForMap(String command, {String? windowId, Map<String, dynamic>? params}) Future<Map<String, dynamic>?>
Send a command expecting a Map result.
inherited
setCursor(String id, SystemMouseCursor cursor) Future<void>
Set cursor style.
setPassthrough(String id, {bool enabled = true, List<Rect>? regions}) Future<void>
Enable click passthrough.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited