clearShowGuard method

void clearShowGuard(
  1. String paletteId
)

Explicitly clear the show guard for a palette.

Use this when you intentionally want to allow re-showing immediately, e.g., after a deliberate user action like clicking a toggle button.

Implementation

void clearShowGuard(String paletteId) => _showGuard.clear(paletteId);