isShowBlocked method

bool isShowBlocked(
  1. String paletteId
)

Check if showing a palette is currently blocked by the show guard.

The show guard prevents re-showing a palette immediately after it was dismissed via click-outside, which would cause a show/dismiss loop.

Implementation

bool isShowBlocked(String paletteId) => _showGuard.isBlocked(paletteId);