NativeEvent class

An event received from the native layer.

Constructors

NativeEvent({required String service, required String event, String? windowId, Map<String, dynamic> data = const {}})
const
NativeEvent.fromMap(Map<String, dynamic> map)
factory

Properties

data Map<String, dynamic>
Event data.
final
event String
The event name.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
service String
The service that emitted this event.
final
windowId String?
The window ID this event is about (null for global events).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited