NativeRect class

A simple rectangle with position and size for FFI operations.

Named NativeRect to avoid conflicts with dart:ui's Rect.

Constructors

NativeRect(double x, double y, double width, double height)
const

Properties

bottom double
no setter
hashCode int
The hash code for this object.
no setterinherited
height double
final
left double
no setter
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top double
no setter
width double
final
x double
final
y double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited