ScreenInfo class

Information about a screen/monitor.

Constructors

ScreenInfo({required int index, required Rect bounds, required Rect workArea, required double scaleFactor, required bool isPrimary})
const
ScreenInfo.fromMap(Map<String, dynamic> map)
factory

Properties

bounds Rect
final
hashCode int
The hash code for this object.
no setterinherited
index int
final
isPrimary bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaleFactor double
final
workArea Rect
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited