getCursorRectAt method

Rect? getCursorRectAt(
  1. int offset
)

Get the cursor rect at a specific text offset.

Returns the rect in local coordinates (relative to the TextField). Returns null if the tracker is not attached or RenderEditable not found.

Implementation

Rect? getCursorRectAt(int offset) {
  final renderEditable = _renderEditable;
  if (renderEditable == null) return null;

  return renderEditable.getLocalRectForCaret(TextPosition(offset: offset));
}