VisibilityClient class

Client for VisibilityService.

Handles show, hide, opacity.

Inheritance

Constructors

VisibilityClient(NativeBridge bridge)

Properties

bridge NativeBridge
Protected access to bridge for subclasses that need direct bridge access.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceName String
The service name (must match native side).
no setteroverride

Methods

dispose() → void
Clean up all subscriptions.
inherited
getOpacity(String id) Future<double>
Get current opacity.
hide(String id, {bool animate = true}) Future<void>
Hide a window.
isVisible(String id) Future<bool>
Get current visibility state.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onEvent(String eventName, void callback(NativeEvent)) → void
Subscribe to events from this service.
inherited
onHidden(String id, void callback()) → void
Called when window becomes hidden.
onHideStart(String id, void callback()) → void
Called when hide animation starts.
onShown(String id, void callback()) → void
Called when window becomes visible.
onShowStart(String id, void callback()) → void
Called when show animation starts.
onWindowEvent(String windowId, String eventName, void callback(NativeEvent)) → void
Subscribe to events for a specific window.
inherited
send<T>(String command, {String? windowId, Map<String, dynamic>? params}) Future<T?>
Send a command to this service.
inherited
sendFireAndForget(String command, {String? windowId, Map<String, dynamic>? params}) → void
Send a command, fire and forget.
inherited
sendForMap(String command, {String? windowId, Map<String, dynamic>? params}) Future<Map<String, dynamic>?>
Send a command expecting a Map result.
inherited
setOpacity(String id, double opacity, {bool animate = false, int? durationMs}) Future<void>
Set window opacity.
show(String id, {bool animate = true, bool focus = true}) Future<void>
Show a window.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited