windowBounds property
The palette's window bounds in screen coordinates.
This must be set before converting local positions to screen coordinates. Typically set by querying the palette's own window bounds.
Implementation
ScreenRect? windowBounds;
The palette's window bounds in screen coordinates.
This must be set before converting local positions to screen coordinates. Typically set by querying the palette's own window bounds.
ScreenRect? windowBounds;