AnimationClient class
Client for AnimationService.
Runs smooth 60fps animations natively.
- Inheritance
-
- Object
- ServiceClient
- AnimationClient
Constructors
- AnimationClient(NativeBridge bridge)
Properties
- bridge → NativeBridge
-
Protected access to bridge for subclasses that need direct bridge access.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceName → String
-
The service name (must match native side).
no setteroverride
Methods
-
animate(
String id, {required AnimatableProperty property, required double from, required double to, required int durationMs, String curve = 'easeOut', int repeat = 1, bool autoReverse = false}) → Future< void> - Animate a property.
-
animateMultiple(
String id, {required List< PropertyAnimation> animations, required int durationMs, String curve = 'easeOut'}) → Future<void> - Animate multiple properties together.
-
dispose(
) → void -
Clean up all subscriptions.
inherited
-
isAnimating(
String id, AnimatableProperty property) → Future< bool> - Check if a property is animating.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onAnyCompleted(
String id, void callback(AnimatableProperty)) → void - Called when any animation completes.
-
onCompleted(
String id, AnimatableProperty property, void callback()) → void - Called when an animation completes.
-
onEvent(
String eventName, void callback(NativeEvent)) → void -
Subscribe to events from this service.
inherited
-
onWindowEvent(
String windowId, String eventName, void callback(NativeEvent)) → void -
Subscribe to events for a specific window.
inherited
-
send<
T> (String command, {String? windowId, Map< String, dynamic> ? params}) → Future<T?> -
Send a command to this service.
inherited
-
sendFireAndForget(
String command, {String? windowId, Map< String, dynamic> ? params}) → void -
Send a command, fire and forget.
inherited
-
sendForMap(
String command, {String? windowId, Map< String, dynamic> ? params}) → Future<Map< String, dynamic> ?> -
Send a command expecting a Map result.
inherited
-
stop(
String id, AnimatableProperty property) → Future< void> - Stop animation on a property.
-
stopAll(
String id) → Future< void> - Stop all animations on a window.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited