GradientBorder class
Configuration for an animated gradient border around a palette.
Used with PaletteScaffold.border to add a rotating gradient border that expands the window size (doesn't shrink content).
PaletteScaffold(
border: GradientBorder(width: 8.0),
child: MyContent(),
)
Constructors
-
GradientBorder({double width = 4.0, List<
Color> colors = const [Color(0xFF6366F1), Color(0xFF8B5CF6), Color(0xFFEC4899), Color(0xFF6366F1)], Duration animationDuration = const Duration(seconds: 3), double? cornerRadius}) -
const
- GradientBorder.subtle()
-
Subtle indigo border - thin and elegant.
const
- GradientBorder.vibrant()
-
Vibrant rainbow border - bold and eye-catching.
const
Properties
- animationDuration → Duration
-
Duration for one complete rotation of the gradient.
final
-
colors
→ List<
Color> -
Colors for the gradient animation.
final
- cornerRadius → double?
-
Corner radius for the border.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double
-
Width of the border stroke in logical pixels.
final
Methods
-
copyWith(
{double? width, List< Color> ? colors, Duration? animationDuration, double? cornerRadius}) → GradientBorder - Creates a copy with the specified fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited