NativeCommand class
A command sent to the native layer.
Constructors
Properties
- command → String
-
The command name.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
params
→ Map<
String, dynamic> -
Command parameters.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- service → String
-
The service to handle this command.
final
- windowId → String?
-
The window ID this command targets (null for global commands).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited