Protocol versioning and compatibility checking.
Ensures the Dart package and native plugin are compatible. Called automatically during PaletteHost.initialize.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
handshake(
NativeBridge bridge) → Future< void> - Perform protocol handshake with native.
Constants
- maxNativeVersion → const int
- Maximum native protocol version this Dart package supports.
- minNativeVersion → const int
- Minimum native protocol version this Dart package supports.
- version → const int
- Current Dart protocol version.