ScreenInfo class
Information about a screen/monitor.
Constructors
- ScreenInfo({required int index, required Rect bounds, required Rect workArea, required double scaleFactor, required bool isPrimary})
-
const
-
ScreenInfo.fromMap(Map<
String, dynamic> map) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited