ZOrderClient class
Client for ZOrderService.
Handles window layering and pinning.
- Inheritance
-
- Object
- ServiceClient
- ZOrderClient
Constructors
- ZOrderClient(NativeBridge bridge)
Properties
- bridge → NativeBridge
-
Protected access to bridge for subclasses that need direct bridge access.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceName → String
-
The service name (must match native side).
no setteroverride
Methods
-
bringToFront(
String id) → Future< void> - Bring window to front.
-
dispose(
) → void -
Clean up all subscriptions.
inherited
-
getZIndex(
String id) → Future< int> - Get current z-index.
-
isPinned(
String id) → Future< bool> - Check if window is pinned.
-
moveAbove(
String id, String otherId) → Future< void> - Move window above another.
-
moveBelow(
String id, String otherId) → Future< void> - Move window below another.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onEvent(
String eventName, void callback(NativeEvent)) → void -
Subscribe to events from this service.
inherited
-
onWindowEvent(
String windowId, String eventName, void callback(NativeEvent)) → void -
Subscribe to events for a specific window.
inherited
-
onZOrderChanged(
String id, void callback(int index)) → void - Called when z-order changes.
-
pin(
String id, {PinLevel level = PinLevel.abovePalettes}) → Future< void> - Pin window to always be on top.
-
send<
T> (String command, {String? windowId, Map< String, dynamic> ? params}) → Future<T?> -
Send a command to this service.
inherited
-
sendFireAndForget(
String command, {String? windowId, Map< String, dynamic> ? params}) → void -
Send a command, fire and forget.
inherited
-
sendForMap(
String command, {String? windowId, Map< String, dynamic> ? params}) → Future<Map< String, dynamic> ?> -
Send a command expecting a Map result.
inherited
-
sendToBack(
String id) → Future< void> - Send window to back.
-
setZIndex(
String id, int index) → Future< void> - Set explicit z-index.
-
toString(
) → String -
A string representation of this object.
inherited
-
unpin(
String id) → Future< void> - Unpin window.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited